document.addEventListener('DOMContentLoaded', function() { 

    // Obtener la dirección IP del div .mobileaccess si existe
    const mobileAccessDiv = document.querySelector('.mobileaccess');
    const baseURL = mobileAccessDiv ? `http://${mobileAccessDiv.textContent.trim()}/` : '/';

    function attachEvents(id) {
        const floppy = document.getElementById(id);
        const li = floppy.querySelector('li'); 

        li.addEventListener('click', function() {
            let options;
            if (id === "floppyA") {
                options = [
                    'Disquetera de 3.5"',
                    'Disquetera de 3"',
                    'Archivo DSK',
                    'Desactivada'
                ];
            } else {
                options = [
                    'Disquetera de 3.5"',
                    'Disquetera de 3"',
                    'Archivo DSK',
                    'Desactivada',
                    'Interfaz Local'
                ];
            }

            const ul = this.parentNode; 

            ul.innerHTML = ''; 

            for (let option of options) {
                const newLi = document.createElement('li'); 
                const link = document.createElement('a');
                
                link.href = `javascript:void(0)`; // Evitar la navegación directa
                link.textContent = option;

                link.addEventListener('click', function(event) {
                    event.preventDefault(); // Evitar la navegación

                    // Realizar la solicitud AJAX
                    fetch(`${baseURL}setDrive?drive=${id}&option=${encodeURIComponent(option)}`)
                        .then(response => {
                            if (response.status === 200) {
                                return response.text();
                            }
                            throw new Error('Error en la petición');
                        })
                        .then(data => {
                            // Reemplazar el div existente con el nuevo div de la respuesta
                            const parser = new DOMParser();
                            const newDoc = parser.parseFromString(data, 'text/html');
                            const newDiv = newDoc.querySelector(`.floppy[id="${id}"]`);
                            const existingDiv = document.querySelector(`.floppy[id="${id}"]`);
                            existingDiv.replaceWith(newDiv);
                            
                            // Desplazarse hacia arriba
                            window.scrollTo(0, 0);
                            
                            // Vuelve a adjuntar los eventos al nuevo div
                            attachEvents(id);
                        })
                        .catch(error => {
                            console.error('Error:', error);
                        });
                });

                newLi.appendChild(link);

                if (option.trim() === this.textContent.trim()) { 
                    newLi.classList.add('selected'); 
                }

                ul.appendChild(newLi); 
            }
        });

        const selectedDskLi = floppy.querySelector('.selected-dsk-title + ul li');
        if (selectedDskLi) {
            selectedDskLi.addEventListener('click', function() {
                if (li.textContent.trim() === 'Archivo DSK') {
                    // Contraer todos los <li> expandidos dentro del <div> con clase "sdfiles"
                    const expandedItems = document.querySelectorAll('.sdfiles li');
                    expandedItems.forEach(item => {
                        // Eliminar botones
                        const buttons = item.querySelectorAll('button');
                        buttons.forEach(button => button.remove());

                        // Eliminar el mensaje de respuesta si existe
                        const responseDiv = item.querySelector('.response');
                        if (responseDiv) {
                            responseDiv.remove();
                        }
                    });

                    const sdFilesUl = document.querySelector('.sdfiles ul').cloneNode(true); // Clonar el ul
                    const dskFilesLis = Array.from(sdFilesUl.querySelectorAll('li.dsk, li.dsk-ext')); // Filtrar por clase

                    const ul = this.parentNode;
                    ul.innerHTML = '';

                    // Añadir la opción "Ningún DSK seleccionado"
                    const noDskLi = document.createElement('li');
                    const noDskLink = document.createElement('a');
                    noDskLink.href = `javascript:void(0)`; // Evitar la navegación directa
                    noDskLink.textContent = 'Ningún DSK seleccionado';

                    noDskLink.addEventListener('click', function(event) {
                        event.preventDefault(); // Evitar la navegación

                        // Realizar la solicitud AJAX
                        fetch(`${baseURL}setDrive?drive=${id}&option=${encodeURIComponent('Archivo DSK')}&file=none`)
                            .then(response => {
                                if (response.status === 200) {
                                    return response.text();
                                }
                                throw new Error('Error en la petición');
                            })
                            .then(data => {
                                // Reemplazar el div existente con el nuevo div de la respuesta
                                const parser = new DOMParser();
                                const newDoc = parser.parseFromString(data, 'text/html');
                                const newDiv = newDoc.querySelector(`.floppy[id="${id}"]`);
                                const existingDiv = document.querySelector(`.floppy[id="${id}"]`);
                                existingDiv.replaceWith(newDiv);
                                // Desplazarse hacia arriba
                                window.scrollTo(0, 0);
                                // Vuelve a adjuntar los eventos al nuevo div
                                attachEvents(id);
                            })
                            .catch(error => {
                                console.error('Error:', error);
                            });
                    });

                    noDskLi.appendChild(noDskLink);
                    ul.appendChild(noDskLi);

                    for (let dskLi of dskFilesLis) {
                        const dskFile = dskLi.textContent.trim();
                        const newLi = dskLi.cloneNode(true); // Clonar el li

                        const link = newLi.querySelector('a');
                        link.href = `javascript:void(0)`; // Evitar la navegación directa
                        link.addEventListener('click', function(event) {
                            event.preventDefault(); // Evitar la navegación

                            // Realizar la solicitud AJAX
                            fetch(`${baseURL}setDrive?drive=${id}&option=${encodeURIComponent('Archivo DSK')}&file=${encodeURIComponent(dskFile)}`)
                                .then(response => {
                                    if (response.status === 200) {
                                        return response.text();
                                    }
                                    throw new Error('Error en la petición');
                                })
                                .then(data => {
                                    // Reemplazar el div existente con el nuevo div de la respuesta
                                    const parser = new DOMParser();
                                    const newDoc = parser.parseFromString(data, 'text/html');
                                    const newDiv = newDoc.querySelector(`.floppy[id="${id}"]`);
                                    const existingDiv = document.querySelector(`.floppy[id="${id}"]`);
                                    existingDiv.replaceWith(newDiv);
                                    // Desplazarse hacia arriba
                                    window.scrollTo(0, 0);
                                    // Vuelve a adjuntar los eventos al nuevo div
                                    attachEvents(id);
                                })
                                .catch(error => {
                                    console.error('Error:', error);
                                });
                        });
                        
                        if (dskFile === this.textContent.trim()) { 
                            newLi.classList.add('selected'); 
                        }

                        ul.appendChild(newLi); 
                    }

                }
            });
        }

        // Asignar eventos a los botones "Cara A" y "Cara B"
        const swapButtons = document.querySelectorAll(`.floppy[id="${id}"] button[side-swap]`);
        swapButtons.forEach(function(button) {
            button.addEventListener('click', function() {
                const floppyElement = this.closest('.floppy');
                const floppyId = floppyElement.getAttribute('floppy-drive-id');
                const side = this.getAttribute('side-swap');
                Command_swapSide(this, floppyId, side);
            });
        });

    }

    const floppyElements = ['floppyA', 'floppyB']; // IDs de tus disqueteras

    floppyElements.forEach(function(id) {
        attachEvents(id);
    });


    const fileItems = document.querySelectorAll('.sdfiles li');

    fileItems.forEach(item => {
        item.addEventListener('click', function() {
            // Contraer cualquier otro <li> expandido
            fileItems.forEach(otherItem => {
                if (otherItem !== this) {
                    // Eliminar botones
                    const buttons = otherItem.querySelectorAll('button');
                    buttons.forEach(button => button.remove());
                }

                // Eliminar el mensaje de respuesta si existe (movido fuera de la condición anterior)
                const responseDiv = otherItem.querySelector('.response');
                if (responseDiv) {
                    responseDiv.remove();
                }
            });

            // Si el <li> actual ya está expandido, contraerlo
            if (this.querySelector('button')) {
                const buttons = this.querySelectorAll('button');
                buttons.forEach(button => button.remove());
                return;
            }

            const fileName = this.querySelector('a').textContent;
            let buttonsHtml = '';

            // Añadir botones "Disquetera A" y "Disquetera B" si el <li> tiene la clase "dsk" o "dsk-ext"
            if (this.classList.contains('dsk') || this.classList.contains('dsk-ext')) {
                buttonsHtml += `
                    <button type="submit" id="driveAButton">Disquetera A</button>
                    <button type="submit" id="driveBButton">Disquetera B</button>
                `;
            }

            buttonsHtml += `
                <button type="submit" class="download">Descargar</button>
                <button type="submit" class="view">Ver</button>
                <button type="submit" class="delete">Eliminar</button>
            `;

            this.innerHTML += buttonsHtml;
            
            // Agregar el comportamiento al botón "Disquetera A"
            let driveAButton = this.querySelector('#driveAButton');
            if (driveAButton) {
                driveAButton.addEventListener('click', function(event) {
                    event.stopPropagation();
                    handleDriveButton('floppyA', fileName, item);
                });
            }

            // Agregar el comportamiento al botón "Disquetera B"
            let driveBButton = this.querySelector('#driveBButton');
            if (driveBButton) {
                driveBButton.addEventListener('click', function(event) {
                    event.stopPropagation();
                    handleDriveButton('floppyB', fileName, item);
                });
            }

            // Agregar el comportamiento al botón "Ver datos"
            this.querySelector('.view').addEventListener('click', function(event) {
                event.stopPropagation();
                window.location.href = `/readDSK?name=${fileName}`;
            });

            // Agregar el comportamiento al botón "Ver datos"
            this.querySelector('.download').addEventListener('click', function(event) {
                event.stopPropagation();
                window.location.href = `/download?name=${fileName}`;
            });

            const deleteButton = this.querySelector('.delete');
            deleteButton.addEventListener('click', function(event) {
                event.stopPropagation();
                if (this.textContent === 'Eliminar') {
                    this.textContent = 'Confirmar';
                } else if (this.textContent === 'Confirmar') {
                    // Si ya hay un div de respuesta, lo eliminamos
                    const existingResponseDiv = item.querySelector('.response');
                    if (existingResponseDiv) {
                        existingResponseDiv.remove();
                    }

                    // Mostrar el mensaje "Eliminando..."
                    const responseDiv = document.createElement('div');
                    responseDiv.className = 'response';
                    responseDiv.textContent = 'Eliminando...';
                    item.appendChild(responseDiv);

                    fetch(`/deleteFile?file=${fileName}`)
                        .then(response => {
                            if (response.status === 200) {
                                return response.text();
                            }
                            throw new Error('Error en la petición');
                        })
                        .then(data => {
                            // Reemplazar el mensaje "Eliminando..." con la respuesta del servidor
                            responseDiv.textContent = data;

                            if (data === 'Archivo eliminado correctamente') {
                                // Quitar los botones
                                const buttons = item.querySelectorAll('button');
                                buttons.forEach(btn => btn.remove());

                                // Iniciar la cuenta atrás
                                let countdown = 3;
                                const countdownDiv = document.createElement('div');
                                countdownDiv.textContent = `Quitando del listado en ${countdown}...`;
                                item.appendChild(countdownDiv);

                                const interval = setInterval(() => {
                                    countdown--;
                                    if (countdown <= 0) {
                                        clearInterval(interval);
                                        item.remove();
                                    } else {
                                        countdownDiv.textContent = `Quitando del listado en ${countdown}...`;
                                    }
                                }, 1000);
                            }
                        })
                        .catch(error => {
                            console.error('Error:', error);
                            responseDiv.textContent = 'Error al eliminar el archivo.';
                        });
                }
            });
        });
    });


    function handleDriveButton(driveId, fileName, listItem) {
        fetch(`${baseURL}setDrive?drive=${driveId}&option=${encodeURIComponent('Archivo DSK')}&file=${encodeURIComponent(fileName)}`)
            .then(response => {
                if (response.status === 200) {
                    return response.text();
                }
                throw new Error('Error en la petición');
            })
            .then(data => {
                // Reemplazar el div existente con el nuevo div de la respuesta
                const parser = new DOMParser();
                const newDoc = parser.parseFromString(data, 'text/html');
                const newDiv = newDoc.querySelector(`.floppy[id="${driveId}"]`);
                const existingDiv = document.querySelector(`.floppy[id="${driveId}"]`);
                existingDiv.replaceWith(newDiv);

                // Desplazarse hacia arriba
                window.scrollTo(0, 0);
                // Vuelve a adjuntar los eventos al nuevo div
                attachEvents(driveId);

                // Contraer el <li> quitando los botones
                const buttons = listItem.querySelectorAll('button');
                buttons.forEach(button => button.remove());
            })
            .catch(error => {
                console.error('Error:', error);
            });
    }


    function Command_swapSide(buttonElement, floppyId, side) {
      // Determinar el ID del floppy drive (0 para A, 1 para B)
      var command = 'side_swap';
      var errorDivId = `${command}-error`;

      // Realizar la solicitud GET
      var xhr = new XMLHttpRequest();
      xhr.open('GET', `${baseURL}avrcommand?command=${command}&arg0=${floppyId}&arg1=${side}`, true);
      xhr.onreadystatechange = function() {
        if (xhr.readyState === 4) { // Si la solicitud se completó
          if (xhr.status === 200) { // Si el estado es OK
            Command_handleResponse(xhr.responseText, buttonElement, errorDivId);
          } else {
            Command_displayError('Error: no se recibió respuesta.', errorDivId);
          }
        }
      };
      xhr.send();
    }


    function Command_handleResponse(response, buttonElement, errorDivId) {
      var errorMessageDiv = document.getElementById(errorDivId);
      if (!errorMessageDiv) {
        console.error(`Elemento de mensaje de error con id ${errorDivId} no encontrado.`);
        return;
      }

      errorMessageDiv.textContent = ''; // Limpiar mensaje de error

      // Determinar la clase 'selected' según la respuesta
      if (response === 'sides_swapped' || response === 'sides_default') {
        var parentDiv = buttonElement.parentElement;
        var buttons = parentDiv.getElementsByTagName('button');
        for (var i = 0; i < buttons.length; i++) {
          buttons[i].classList.remove('selected');
        }
        buttonElement.classList.add('selected');
      } else {
        Command_displayError('Error: no se pudo hacer la acción solicitada.', errorDivId);
      }
    }


    function Command_displayError(message, errorDivId) {
      var errorMessageDiv = document.getElementById(errorDivId);
      if (!errorMessageDiv) {
        console.error(`Elemento de mensaje de error con id ${errorDivId} no encontrado.`);
        return;
      }
      errorMessageDiv.textContent = message;
    }

    
});



